# Description

*  Simulation of the cocurrent flow of air and water in a vertical pipe (d=51.2mm, l=3m) at 303.15K
*  Setups cover 86 different superficial velocity combinations, ranging from 0.0025m/s to 0.543m/s for the air phase and 0.0405 to 4.047m/s for the water phase (MTLoop M01, see Prasser et al., 2003)
*  Superficial velocity combination (defined at T=293.15K and p=1013hPa) and initial/inlet bubble size distribution is determined by the [case number](https://gitlab.hzdr.de/openfoam/fwdc/Cases/-/blob/master/baseline/2005_Lucas_et_al/validation/caseMatrix)
*  Various [templated setups](https://gitlab.hzdr.de/openfoam/fwdc/Cases/-/tree/master/baseline/2005_Lucas_et_al/templates) are provided and briefly described below
*  Users can select the case number to be simulated either directly in the [Allrun script](https://gitlab.hzdr.de/openfoam/fwdc/Cases/-/blob/master/baseline/2005_Lucas_et_al/templates/developing/Allrun), or, in the context of a Snakemake workflow, provide a list of cases in the corresponding [yaml file](https://gitlab.hzdr.de/openfoam/fwdc/Cases/-/blob/master/baseline.yaml)

# Technical Information

The water used in the experiment was deionised.

## General

*  Axisymmetric setup ("wedge")
*  Air is introduced into the domain uniformly through a mass source at the lowest measurement level, using the fvOption framework
*  Developed single phase profiles for the water phase are ensured at the inlet by using mapped boundary conditions

## fullyDeveloped* setups

*  Aims at validating models for interfacial exchange of momentum and bubble-induced turbulence
*  Aims to answer the following research question: Provided the bubble size distribution could be frozen, what would the fully developed profiles look like? How well do the resulting profiles agree with the (nearly developed) experimentally determined ones at the highest measurement level?
*  Fixed density, i.e. no dilatation
*  Fixed size distribution based on the measurements at the highest level
*  Flow develops over the domain length which has no physical meaning anymore
*  fullyDevelopedVelocityGroups: Dispersed phase is split into 4 velocity groups, according to the characteristic turning points of the lift force coefficient model of Tomiyama et al. (2002)

## homogeneous setup

*  Single-cell setup
*  Standalone solution of the population balance equation, using the volume averaged results from the fullyDeveloped* cases at the highest measurement level
*  Useful for a quick evaluation of the validity of a coalescence and breakup model combination and for tuning coefficients

## developing* setups

*  Study of the developing flow, including dilatation, coalescence and breakup
*  Initial/inlet size distribution based on measurements at the lowest level
*  developingVelocityGroups: Dispersed phase is split into 4 velocity groups, according to the characteristic turning points of the lift force coefficient model of Tomiyama et al. (2002)

# Pre-Processing

*  Pre-processing is straight-forward, the user only needs to supply desired case number

# Post-Processing

## Data Validation

| Field     | Validation                    | Reference                        |
| :-------: | :---------------------------: | :------------------------------: |
| alpha.air | m01_97l_01.epsrad_20_bub.dat  | 97/line_alpha.air.xy             |
| U.air     | m01_97l_01.vel.dat            | 97/line_U.air.xy                 |


# Keywords

pipe, circular-cross-section, constant-cross-section, bottom-injection,
vertical-upward, co-current, air-water, polydisperse, incompressible,
filtered-water, steady-state, isothermal, 2D-wedge, two-phase-inlet, pressure-outlet

fullyDeveloped*: fixed-bubble-size, fully-developed
fullyDeveloped: one-gas
fullyDevelopedVelocityGroups: multiple-gas

homogeneous: one-gas, coalescence-breakup, fully-developed

developing*: density-change, coalescence-breakup, developing
developing: one-gas
developingVelocityGroups: multiple-gas


# Additional Remarks

*  Note that the experimental phase fraction profiles were corrected such that the corresponding superficial velocities match those prescribed by the experimental matrix (this is not the case in the raw experimental data)
*  Note that the required physical time, i.e. the setting for the endTime, highly depends on the selected superficial velocity combination and is therefore computed using the `#calc` functionality

# Literature

Prasser et al. (2003). Flow maps and models for transient two-phase flows.
Final Report of Reactor Safety Research Project No.: 150 1215.
Report - No.: FZR-379

Lucas et al. (2005). Development of co-current air-water flow in a vertical
pipe. International Journal of Multiphase Flow, 31, 1304-1328.

Lehnigk (2020). A generalized population balance model for the simulation of
polydisperse multiphase flows within the Euler-Euler framework. TU Dresden.
Phd thesis. Not yet published.
