set linetype 1 lc rgb 'red'     lw 1 dt 1
set linetype 2 lc rgb 'blue'    lw 1 dt 1
set linetype 3 lc rgb 'green'   lw 1 dt 1
set linetype 4 lc rgb 'black'   lw 1 dt 1
set linetype 5 lc rgb 'orange'  lw 1 dt 1
set linetype 6 lc rgb 'gray'    lw 1 dt 1
set linetype 7 lc rgb 'pink'    lw 1 dt 1

set key outside below
set grid

#---PNG---
set terminal pngcairo color noenhanced size 800,600
FType = '.png'

#---Dimensions---
L = 1
g = 0.00919
Ug = sqrt(L*g)
T = L/Ug
R = 0.5
k0 = 0.5*Ug**2

print 'Ug = ', Ug, ' m s^-1'
print 'T = ', T, ' s'

TIMES =     '0'
NUM =       words(TIMES)
TIME(n) =   word(TIMES, n)


#---PNG---
set terminal pngcairo color enhanced size 800,600


#---PID-Controller---
ZFILE(n) =  '../postProcessing/bubbleProperties/'.TIME(n).'/bubbleProperties.dat'
UFILE(n) =  '../postProcessing/probes/'.TIME(n).'/U.water'

set xlabel  't'
set ylabel  'control variable: z_b'
set ytics   nomirror
set y2label 'controlled variable: U_z'
set y2tics
set xzeroaxis lt 2 lw 2 dt 3

set output  'PIDcontroller_z'.FType
set title   'PID variables'

plot        for [i=1:NUM] ZFILE(i) u 1:4 w l lt 2 t 'z_b', \
            for [i=1:NUM] UFILE(i) u 1:4 '%lf (%lf %lf %lf) (%lf %lf %lf)' axes x1y2 w l lt 3 t 'U_z'

unset y2label
unset y2tics
set ytics


#---Radial-Profiles-Center---
FILE      = '../postProcessing/radialVelocityProfile_surfaceCenter.dat'

set output  'radialProfile_U'.FType
set title   'Radial Profile of Velocity at Center of Bubble'
set xlabel  'r/D_b'
set ylabel  '<U>/U_b'
set arrow from 0.5, graph 0 to 0.5, graph 1 nohead

plot        FILE u 1:($4/Ug) w l t "<U_z>", \
            FILE u 1:($2/Ug) w l t "<U_r>", \
            FILE u 1:($3/Ug) w l t "<U_{/Symbol f}>"

set output  'radialProfile_UFluc_center'.FType
set title   'Radial Profile of Velocity Fluctuation at Center of Bubble'
set ylabel "<U_i^' U_j^'>/U_b^2"
set xrange  [0:1.2]
plot        FILE u 1:($7/Ug**2) w l t "<U_z'U_z'>", \
            FILE u 1:($5/Ug**2) w l t "<U_r'U_r'>", \
            FILE u 1:($6/Ug**2) w l t "<U_{/Symbol f}'U_{/Symbol f}'>", \
            FILE u 1:($9/Ug**2) w l t "<U_r'U_z'>"

set output  'radialProfile_K_center'.FType
set title   'Radial Profile of Turbulent Kinetic Energy at Center of Bubble'
set ylabel  '<k>/(0.5 U_b^2)'
plot        FILE u 1:($11/k0) w l notitle

unset arrow
unset xzeroaxis
unset title


#---3D-Trajectory---
FILE =  '../postProcessing/3Dtrajectory.dat'

set output  '3Dtrajectory'.FType
set grid
set view equal xy
set view 70,30,1.3,1

set xtics 1  offset 0,-0.2
set ytics 1  offset 0.9,-0.2
set ztics 10 offset 0.8
set ticslevel 0

set xlabel 'x' offset 0,-0.5
set ylabel 'y' offset 1.5,-1
set zlabel 'z' offset 2

set xrange [-2:2]
set yrange [-2:2]

splot FILE u 2:3:4      w l lt 1        notitle, \
      FILE u 2:3:($4*0) w l lt 1 lw 0.1 notitle
